@@ -1,13 +1,5 @@
 var merge = require('../index');
 
-describe('utils-merge', function() {
-    
-  it('should export function', function() {
-    expect(merge).to.be.a('function');
-  });
-  
-});
-
 describe('merge', function() {
   
   describe('an object', function() {
